from .base import BaseBeanProxy, ClassBeanProxy, AspectClassBeanProxy, AsyncCallClassBeanProxy
from .delay import DelayAutowiredClassBeanProxy, AsyncCallDelayAutowiredClassBeanProxy, DelayConfigAutowiredClassBeanProxy
